# eric7.Debugger.StartDialog

Module implementing the Start Program dialog.

### Global Attributes

None

### Classes

StartDialog | Class implementing the Start Program dialog.

### Functions

None

## StartDialog

Class implementing the Start Program dialog.

It implements a dialog that is used to start an application for debugging. It asks the user to enter the commandline parameters, the working directory and whether exception reporting should be disabled.

### Derived from

QDialog

### Class Attributes

None

### Class Methods

None

### Methods

StartDialog | Constructor
__clearHistories | Private slot to clear the combo boxes lists and record a flag to clear the lists.
__editHistory | Private slot to edit a history list.
clearHistories | Public method to test, if histories shall be cleared.
getCoverageData | Public method to retrieve the coverage related data entered into this dialog.
getData | Public method to retrieve the data entered into this dialog.
getDebugData | Public method to retrieve the debug related data entered into this dialog.
getGlobalOverrideData | Public method to retrieve the global configuration override data entered into this dialog.
getHistories | Public method to get the lists of histories.
getProfilingData | Public method to retrieve the profiling related data entered into this dialog.
historiesModified | Public method to test for modified histories.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_modFuncCombo_editTextChanged | Private slot to enable/disable the OK button.

### Static Methods

None

#### StartDialog (Constructor)

StartDialog(caption, lastUsedVenvName, argvList, wdList, envList, exceptions, parent=None, dialogType=0, modfuncList=None, tracePython=False, autoClearShell=True, autoContinue=True, enableMultiprocess=False, multiprocessNoDebugHistory=None, configOverride=None, forProject=False, scriptName="", scriptsList=None)

Constructor

caption (str)
  the caption to be displayed
lastUsedVenvName (str)
  name of the most recently used virtual environment
argvList (list of str)
  history list of command line arguments
wdList (list of str)
  history list of working directories
envList (list of str)
  history list of environment parameter settings
exceptions (bool)
  exception reporting flag
parent (QWidget)
  parent widget of this dialog
dialogType (int (0 to 3))
  type of the start dialog
  - 0 = start debug dialog
  - 1 = start run dialog
  - 2 = start coverage dialog
  - 3 = start profile dialog
modfuncList (list of str)
  history list of module functions
tracePython (bool)
  flag indicating if the Python library should be traced as well
autoClearShell (bool)
  flag indicating, that the interpreter window should be cleared automatically
autoContinue (bool)
  flag indicating, that the debugger should not stop at the first executable line
enableMultiprocess (bool)
  flag indicating the support for multi process debugging
multiprocessNoDebugHistory (list of str)
  list of lists with programs not to be debugged
configOverride (dict)
  dictionary containing the global config override data
forProject (bool)
  flag indicating to get the parameters for a run/debug/... action for a project
scriptName (str)
  name of the script
scriptsList (list of str)
  history list of script names

#### StartDialog.__clearHistories

__clearHistories()

Private slot to clear the combo boxes lists and record a flag to clear the lists.

#### StartDialog.__editHistory

__editHistory()

Private slot to edit a history list.

#### StartDialog.clearHistories

clearHistories()

Public method to test, if histories shall be cleared.

Return:
  flag indicating histories shall be cleared

Return Type:
  bool

#### StartDialog.getCoverageData

getCoverageData()

Public method to retrieve the coverage related data entered into this dialog.

Return:
  flag indicating erasure of coverage info

Return Type:
  bool

#### StartDialog.getData

getData()

Public method to retrieve the data entered into this dialog.

Return:
  a tuple of virtual environment, script name, argv, workdir, environment, exceptions flag, clear interpreter flag and run in console flag

Return Type:
  tuple of (str, str, str, str, str, bool, bool, bool)

#### StartDialog.getDebugData

getDebugData()

Public method to retrieve the debug related data entered into this dialog.

Return:
  a tuple of a flag indicating, if the Python library should be traced as well, a flag indicating, that the debugger should not stop at the first executable line, a flag indicating to support multi process debugging and a space separated list of programs not to be debugged

Return Type:
  tuple of (bool, bool, bool, str)

#### StartDialog.getGlobalOverrideData

getGlobalOverrideData()

Public method to retrieve the global configuration override data entered into this dialog.

Return:
  dictionary containing a flag indicating to activate the global override and a flag indicating a redirect of stdin/stdout/stderr

Return Type:
  dict

#### StartDialog.getHistories

getHistories()

Public method to get the lists of histories.

Return:
  tuple containing the histories of script names, command line arguments, working directories, environment settings and no debug programs lists

Return Type:
  tuple of five list of str

#### StartDialog.getProfilingData

getProfilingData()

Public method to retrieve the profiling related data entered into this dialog.

Return:
  flag indicating erasure of profiling info

Return Type:
  bool

#### StartDialog.historiesModified

historiesModified()

Public method to test for modified histories.

Return:
  flag indicating modified histories

Return Type:
  bool

#### StartDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button (QAbstractButton)
  button that was clicked

#### StartDialog.on_modFuncCombo_editTextChanged

on_modFuncCombo_editTextChanged()

Private slot to enable/disable the OK button.

Up